`cr` - CodeRed Cloud CLI
========================

The official CodeRed Cloud command line tool. Easily deploy your Django, Wagtail, WordPress, or Static HTML sites directly from your terminal or version control system.

https://www.codered.cloud/cli/

---

To contribute, see the [CONTRIBUTING.md](CONTRIBUTING.md) file in this repository.
